====================
Python API reference
====================

This page gives a high-level overview of all public Polars objects, functions and
methods. All classes and functions exposed in the ``polars.*`` namespace are public.


.. grid::

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           dataframe/index

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           lazyframe/index

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           series/index


.. grid::

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           expressions/index
           selectors
           datatype_expr/index

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           functions

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           datatypes
           schema/index


.. grid::

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           io

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           catalog/index

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           config

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           api

        .. toctree::
           :maxdepth: 1

           plugins


.. grid::

    .. grid-item-card::

        .. toctree::
           :maxdepth: 2

           sql/index

    .. grid-item-card::

        .. toctree::
           :maxdepth: 1

           exceptions

        .. toctree::
           :maxdepth: 2

           testing

    .. grid-item-card::

        .. toctree::
           :maxdepth: 1

           metadata
